Axes

Struct Axes 

pub struct Axes {
    pub scale: f64,
}
Axes are a debug structure that indicate the position of the origin of the space as well as the x, y and z directions.

It is also a way to evaluate distances, as it includes spheres with regular spacing. Its only parameter is in fact its size.

Its major downside is that being composed of almost 20 objects, it slows down rendering quite a bit.

Fields

scale: f64

Implementations

Source

impl Axes

pub fn build(self) -> Composite